@@ -2,7 +2,6 @@ from logging import getLogger
 
 from django.core.exceptions import FieldError
 from django.db.models import get_model, Model
-from django.db.models.sql.constants import LOOKUP_SEP
 from django.http import HttpResponse
 
 from ..forms import PartitialForm
@@ -13,6 +12,11 @@ from ..utils.paginator import Paginator
 from ..utils.tools import as_tuple
 
 
+__all__ = 'HandlerMixin',
+
+# Separator used to split filter strings apart.
+LOOKUP_SEP = '__'
+
 logger = getLogger('django.request')
 
 
